AggregateReceiver

Struct AggregateReceiver 

pub struct AggregateReceiver { /* private fields */ }
Receiver to receive the aggregated responses from the BLS Aggregator Service.

Implementations

Source

impl AggregateReceiver

pub async fn receive_aggregated_response( &mut self, ) -> Result<BlsAggregationServiceResponse, BlsAggregationServiceError>

Receives the aggregated response from the BLS Aggregator Service.

Returns

Returns the aggregated response or an error if the channel is closed.