TaskMetadata

Struct TaskMetadata 

pub struct TaskMetadata { /* private fields */ }
Contains the metadata required to initialize a new task.

Implementations

Source

impl TaskMetadata

pub fn new( task_index: TaskIndex, task_created_block: u64, quorum_numbers: Vec<u8>, quorum_threshold_percentages: QuorumThresholdPercentages, time_to_expiry: Duration, ) -> Self

Creates a new instance of TaskMetadata

Arguments
  • task_index - index of the task
  • task_created_block - block number at which the task was created
  • quorum_numbers - quorum numbers which should respond to the task
  • quorum_threshold_percentages - threshold percentages for each quorum
  • time_to_expiry - time until the task expires

Use with_window_duration to set the window duration. If the window duration is not set, it will default to Duration::ZERO.

Returns

A new instance of TaskMetadata

pub fn with_window_duration(self, window_duration: Duration) -> Self

Sets the window duration for the task

Arguments
  • window_duration - The duration of the window to wait for signatures after quorum is reached
Returns

An instance of TaskMetadata with the window duration set