pub struct AggregateReceiver { /* private fields */ }Expand description
Receiver to receive the aggregated responses from the BLS Aggregator Service.
Implementations
Sourceimpl AggregateReceiver
impl AggregateReceiver
Sourcepub async fn receive_aggregated_response(
&mut self,
) -> Result<BlsAggregationServiceResponse, BlsAggregationServiceError>
pub async fn receive_aggregated_response( &mut self, ) -> Result<BlsAggregationServiceResponse, BlsAggregationServiceError>
Receives the aggregated response from the BLS Aggregator Service.
Returns
Returns the aggregated response or an error if the channel is closed.